External Command-line Flags
===========================

.. cmdoption:: --prefix

   Python installation option. See :cite:`InstallingPythonModules`.

.. cmdoption:: --home

   Python installation option. See :cite:`InstallingPythonModules`.

External Environment Variables
==============================

.. envvar:: LD_LIBRARY_PATH

   On Linux, a colon-separated list of directories in which to search for
   ELF libraries at execution-time.


.. envvar:: DYLD_LIBRARY_PATH

   On Mac OS X, a colon separated list of directories that contain libraries.
   The dynamic linker searches these directories before it searches the
   default locations for libraries.
